use ${dd}\ed_episodes_cleaned.dta, clear

keep if emcare_entry_ind==1

order aha provider_name_c

*Keeping 12 months prior and 12 months post entry for each hospital 

gen emcare_l1=emcare_year_entry-1
gen emcare_a1=emcare_year_entry+1

gen emcare_entry1=.
replace emcare_entry1=1 if emcare_l1==year_start & emcare_month_entry==month_start

sort aha year_start month_start
bysort aha: replace emcare_entry1=emcare_entry1[_n-1] if missing(emcare_entry1)
replace emcare_entry1=0 if emcare_entry1==.
replace emcare_entry1=0 if year_start==emcare_a1 & month_start>emcare_month_entry
replace emcare_entry1=0 if year_start>emcare_a1

keep if emcare_entry1==1

egen mgroup=group(year_start month_start)

sort aha year_start month_start
bysort aha mgroup: gen first=_n==1
bysort aha: gen dmark=sum(first)

*Collapse to hospital month level
collapse(mean) phys_charge phys_payment fac_charge fac_payment, by(aha dmark)

*Monthly discontinuity figures for payments and charges
foreach var of varlist phys_charge phys_payment fac_charge fac_payment {

	if "`var'"=="phys_charge" loc titler "Panel B: Physician Charge ($)"
	if "`var'"=="phys_payment" loc titler "Panel C: Physician Payment ($)"
	if "`var'"=="fac_charge" loc titler "Panel D: Facility Charge ($)"
	if "`var'"=="fac_payment" loc titler "Panel E: Facility Payment ($)"


tw scatter `var' dmark, msymbol(circle) || ///
	lpoly `var' dmark if dmark<13, lc(red) lw(medthick) || ///
	lpoly `var' dmark if dmark>=13, lc(red) lw(medthick)  ///
	title("`titler'") ///
	xmtick(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25, tlength(2) tposition(outside)) ///
	xlabel(1 `""t-12" "months""' 7 `""t-6" "months""' 13 `""EmCare" "entry""' 19 `""t+6" "months""' 25 `""t+12" "months""') ///
	xline(13) ///
	legend(col(1) order(1 "Hospital-Month Average" 2 "Local Polynomial Smoothed Monthly Average"))
	graph export ${o}\final_figures\discont_`var'.png, width(1500) height(1000) as(png) replace

	}
	
	
*************************************************************

use ${dd}\ed_episodes_cleaned.dta, clear

keep if emcare_entry_ind==1

order aha provider_name_c

*Keeping 12 months prior and 12 months post entry for each hospital 

gen emcare_l1=emcare_year_entry-1
gen emcare_a1=emcare_year_entry+1

gen emcare_entry1=.
replace emcare_entry1=1 if emcare_l1==year_start & emcare_month_entry==month_start

sort aha year_start month_start
bysort aha: replace emcare_entry1=emcare_entry1[_n-1] if missing(emcare_entry1)
replace emcare_entry1=0 if emcare_entry1==.
replace emcare_entry1=0 if year_start==emcare_a1 & month_start>emcare_month_entry
replace emcare_entry1=0 if year_start>emcare_a1

keep if emcare_entry1==1

egen mgroup=group(year_start month_start)

sort aha year_start month_start
bysort aha mgroup: gen first=_n==1
bysort aha: gen dmark=sum(first)

gen total_eps=1
gen out_eps=1 if in_net_phys_ind==0

*Collapse to hospital month level 
collapse (sum) total_eps out_eps imaging_ind adm_ind proc5_ind, by(aha dmark)

bysort aha dmark: gen oon_rate=out_eps/total_eps
bysort aha dmark: gen im_rate=imaging_ind/total_eps
bysort aha dmark: gen adm_rate=adm_ind/total_eps
bysort aha dmark: gen cpt_rate=proc5_ind/total_eps

*Monthly discontinuity figures for imaging, admissions, CPT
foreach var of varlist im_rate adm_rate cpt_rate {

	if "`var'"=="im_rate" loc titler "Panel F: Episodes Involving an Imaging Study (%)"
	if "`var'"=="adm_rate" loc titler "Panel G: Admissions Rate (%)"
	if "`var'"=="cpt_rate" loc titler "Panel H: Rate of Using CPT 99285 (%)"


if "`var'"=="adm_rate" {
	preserve
	drop if adm_rate>.22
tw scatter `var' dmark, msymbol(circle) || ///
	lpoly `var' dmark if dmark<13, lc(red) lw(medthick) || ///
	lpoly `var' dmark if dmark>=13, lc(red) lw(medthick) /// 
	xmtick(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25, tlength(2) tposition(outside)) ///
	xlabel(1 `""t-12" "months""' 7 `""t-6" "months""' 13 `""EmCare" "entry""' 19 `""t+6" "months""' 25 `""t+12" "months""') ///
	title("`titler'") ///
	xline(13) ///
	ylabel(0 "0" .1 "10" .2 "20") ///
	legend(col(1) order(1 "Hospital-Month Average" 2 "Local Polynomial Smoothed Monthly Average"))
	graph export ${o}\final_figures\discont_`var'.png, width(1500) height(1000) as(png) replace
	restore
	}
	
 if "`var'"!="adm_rate" {
	tw scatter `var' dmark, msymbol(circle) || ///
	lpoly `var' dmark if dmark<13, lc(red) lw(medthick) || ///
	lpoly `var' dmark if dmark>=13, lc(red) lw(medthick) /// 
	xmtick(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25, tlength(2) tposition(outside)) ///
	xlabel(1 `""t-12" "months""' 7 `""t-6" "months""' 13 `""EmCare" "entry""' 19 `""t+6" "months""' 25 `""t+12" "months""') ///
	title("`titler'") ///
	ylabel(0 "0" .2 "20" .4 "40" .6 "60" .8 "80" 1 "100" ) ///
	xline(13) ///
	legend(col(1) order(1 "Hospital-Month Average" 2 "Local Polynomial Smoothed Monthly Average"))
	graph export ${o}\final_figures\discont_`var'.png, width(1500) height(1000) as(png) replace

	}
	

}	
	
**************************************************
**************************************************
use ${dd}\ed_episodes_cleaned.dta, clear

*Only looking at previously low OON hospitals 
keep if aha=="6XXXXX1" | aha=="6XXXXX2" | aha=="6XXXXX3" | aha=="6XXXXX4" | aha=="6XXXXX5" | aha=="6XXXXX6" | aha=="6XXXXX7" | aha=="6XXXXX8"
keep if emcare_entry_ind==1

order aha provider_name_c

*Keeping 12 months prior and 12 months post entry for each hospital 

gen emcare_l1=emcare_year_entry-1
gen emcare_a1=emcare_year_entry+1

gen emcare_entry1=.
replace emcare_entry1=1 if emcare_l1==year_start & emcare_month_entry==month_start

sort aha year_start month_start
bysort aha: replace emcare_entry1=emcare_entry1[_n-1] if missing(emcare_entry1)
replace emcare_entry1=0 if emcare_entry1==.
replace emcare_entry1=0 if year_start==emcare_a1 & month_start>emcare_month_entry
replace emcare_entry1=0 if year_start>emcare_a1

keep if emcare_entry1==1

egen mgroup=group(year_start month_start)

sort aha year_start month_start
bysort aha mgroup: gen first=_n==1
bysort aha: gen dmark=sum(first)

gen total_eps=1
gen out_eps=1 if in_net_phys_ind==0

*Collapse to hospital month level 
collapse (sum) total_eps out_eps, by(aha dmark)

bysort aha dmark: gen oon_rate=out_eps/total_eps

*Monthly discontinuity figure for OON rate
foreach var of varlist oon_rate {

if "`var'"=="oon_rate" loc titler "Panel A: Out-of-Network Physician Rate (%)"

tw scatter `var' dmark, msymbol(circle) || ///
	lpoly `var' dmark if dmark<13, lc(red) lw(medthick) || ///
	lpoly `var' dmark if dmark>=13, lc(red) lw(medthick) ///
	ylabel(0 "0" .2 "20" .4 "40" .6 "60" .8 "80" 1 "100" ) ///
	xmtick(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25, tlength(2) tposition(outside)) ///
	xlabel(1 `""t-12" "months""' 7 `""t-6" "months""' 13 `""EmCare" "entry""' 19 `""t+6" "months""' 25 `""t+12" "months""') ///
	title("`titler'") ///
	xline(13) ///
	legend(col(1) order(1 "Hospital-Month Average" 2 "Local Polynomial Smoothed Monthly Average"))
	graph export ${o}\final_figures\discont_`var'.png, width(1500) height(1000) as(png) replace

	}
	
