
use ${dd}\ed_episodes_cleaned.dta, clear

*Defining each separately for summary table
gen hispanic=1 if pat_race==2
gen black=1 if pat_race==3
gen white=1 if pat_race==4

gen oldest=1 if pat_age==1
gen oldestb=1 if pat_age==2
gen oldestc=1 if pat_age==3
gen oldestd=1 if pat_age==4
gen oldeste=1 if pat_age==5
gen oldestf=1 if pat_age==6

foreach var of varlist hispanic black white oldest oldestb oldestc oldestd oldeste oldestf {
	replace `var'=0 if missing(`var')
}


*Adjusting for inflation
local pricelist fac_charge fac_payment phys_charge phys_payment 
foreach l of local pricelist {
replace `l'=`l'*cpi
}

*Summarizing each variable and creating measures
foreach var of varlist phys_payment phys_charge fac_payment fac_charge oon_ind adm_ind imaging_ind ctmri_ind lab_ind los proc1_ind proc2_ind proc3_ind proc4_ind proc5_ind hispanic black white oldest oldestb oldestc oldestd oldeste oldestf charlson6 hist6_calc_allwd hist12_calc_allwd  {
	summ `var', d
	gen `var'1=r(mean)
	gen `var'2=r(sd)
	gen `var'3=r(min)
	gen `var'4=r(p10)
	gen `var'5=r(p25)
	gen `var'6=r(p50)
	gen `var'7=r(p75)
	gen `var'8=r(p90)
	gen `var'9=r(max)
	drop `var'
}

*Reshaping for table
keep *1 *2 *3 *4 *5 *6 *7 *8 *9 
drop proc_per_ep1 er_per_ep2 both_par1 both_par2 rvnu_v* los_ind* aha_mapp8 proc_s*

keep if _n==1
gen num=1
reshape long phys_payment phys_charge fac_payment fac_charge oon_ind adm_ind imaging_ind ctmri_ind lab_ind los proc1_ind proc2_ind proc3_ind proc4_ind proc5_ind hispanic black white oldest oldestb oldestc oldestd oldeste oldestf charlson6 hist6_calc_allwd hist12_calc_allwd, i(num) j(new)
drop num new


xpose, clear varname
order _varname

tempfile temp1
save `temp1', replace

*********************************
*Same idea, but summarizing episodes across hospitals

use ${dd}\ed_episodes_cleaned.dta, clear
gen episode_counter=1

collapse(sum) episode_counter, by(aha)

foreach var of varlist episode_counter  {
	summ `var', d
	gen `var'1=r(mean)
	gen `var'2=r(sd)
	gen `var'3=r(min)
	gen `var'4=r(p10)
	gen `var'5=r(p25)
	gen `var'6=r(p50)
	gen `var'7=r(p75)
	gen `var'8=r(p90)
	gen `var'9=r(max)
	drop `var'
}

keep episode_counter*
keep if _n==1
gen num=1
reshape long episode_counter, i(num) j(new)
drop num new

xpose, clear varname
order _varname

append using `temp1'

outsheet * using ${o}\final_tables\summarystats_lhs.csv, comma replace
 
